//+------------------------------------------------------------------+
//|                                       London Breakout script.mq4 |
//|                                  Copyright  2009, Steve Hopwood |
//|                              http://www.hopwood3.freeserve.co.uk |
//+------------------------------------------------------------------+

/*+------------------------------------------------------------------+
 *
 * Version history:
 *
 * V3.1: [Squalou]
 *     - fixed errors when market price is incompatible with STOP orders:
 *       open LIMIT orders instead of STOP orders in this case;
 *
 * V3: [Squalou]
 *     - added "CloseHalfTradeAtHalfTP"(false) input:
 *       when true, will place orders of half lots each, so that 
 *       half of the orders have full TP and half have half TP targets;
 *     - added more explicit alert/print information;
 *
 * V2: [Squalou]
 *     - Buy/Sell Entry/TP/SL prices left to 0 are "imported" from 
 *       GlobalVariables set by the "London BreakoutV7.mq4" (or higher) indicator;
 *     
 * This is an improvement of Steve Hopwoods script posted on
 * http://www.forexfactory.com/showthread.php?t=230640
 *
 * It is designed to work with the "London BreakoutV7.mq4" indicator
 * or any higher version of it.
 *
 * You must have loaded the "London BreakoutV7.mq4" indicator (or higher version) on the chart,
 * so that this script can retrieve the corresponding entry/TP/SL levels
 * for the BuyStop and SellStop orders that it will place.
 *
 * Values in this script's inputs left to 0 will automatically be set
 * to the Indicators calculated values, so you don't need to manually input them.
 *
 * (V1): original version, courtesy of Steve Hopwood;
 *
 *+------------------------------------------------------------------+
 */


#property copyright "London Breakout scriptV3.1"
#property link      "http://www.hopwood3.freeserve.co.uk"
#include <WinUser32.mqh>
#include <stdlib.mqh>
#property show_inputs


extern double  Lot=0.02;
extern int     MagicNumber=274693;
extern string  TradeComment="London breakout scriptV3.1";
extern string  objPrefix = "LB-";  // Prefix of London Breakout Indicator objects;
extern string  Usage = "0 values will default to current chart LB values";
extern double  LongPendingEntryPrice;
extern double  LongTP;
extern double  LongSL;
extern double  ShortPendingEntryPrice;
extern double  ShortTP;
extern double  ShortSL;
extern bool    CloseHalfTradeAtHalfTP = false;

extern double  Risk = 2; // risk %


void init()
{

  // replace default 0 inputs with London Breakout Indicator global variables set on the current chart
  if (LongPendingEntryPrice==0) LongPendingEntryPrice = GlobalVariableGet(objPrefix+Symbol()+"-LongEntry");
  if (ShortPendingEntryPrice==0) ShortPendingEntryPrice = GlobalVariableGet(objPrefix+Symbol()+"-ShortEntry");
  if (LongTP==0) LongTP = GlobalVariableGet(objPrefix+Symbol()+"-LongTP");
  if (ShortTP==0) ShortTP = GlobalVariableGet(objPrefix+Symbol()+"-ShortTP");
  if (LongSL==0) LongSL = GlobalVariableGet(objPrefix+Symbol()+"-LongSL");
  if (ShortSL==0) ShortSL = GlobalVariableGet(objPrefix+Symbol()+"-ShortSL");


  LotSize(Risk);

}



//+------------------------------------------------------------------+
//| script program start function                                    |
//+------------------------------------------------------------------+
int start()
{
//----

  Alert("--- START "+WindowExpertName()+" "+Symbol());

  place_breakout_pending_orders (Symbol());
  
  Alert("--- END "+WindowExpertName()+" "+Symbol());

//----
   return(0);
}
   

//+------------------------------------------------------------------+
void place_breakout_pending_orders (string symbol)
//+------------------------------------------------------------------+
{
  int op, ticket;
  double servers_min_stop;

  servers_min_stop = MarketInfo(symbol, MODE_STOPLEVEL) * MarketInfo(symbol, MODE_POINT);

  //Long trade
  if (LongPendingEntryPrice >= Ask+servers_min_stop) op = OP_BUYSTOP; else op = OP_BUYLIMIT;
  if (!CloseHalfTradeAtHalfTP) {
    place_order(symbol, op,"Pending long", Lot, LongPendingEntryPrice, LongSL,  LongTP, MagicNumber);
  } else {
    place_order(symbol, op,"Pending long", Lot/2, LongPendingEntryPrice, LongSL,  LongTP, MagicNumber);
    place_order(symbol, op,"Pending long", Lot/2, LongPendingEntryPrice, LongSL, (LongTP+LongPendingEntryPrice)/2, MagicNumber+1);
  }

  //Short trade
  if (ShortPendingEntryPrice <= Bid-servers_min_stop) op = OP_SELLSTOP; else op = OP_SELLLIMIT;
  if (!CloseHalfTradeAtHalfTP) {
    place_order(symbol, op, "Pending short",Lot, ShortPendingEntryPrice, ShortSL, ShortTP, MagicNumber);
  } else {
    place_order(symbol, op, "Pending short",Lot/2, ShortPendingEntryPrice, ShortSL, ShortTP, MagicNumber);
    place_order(symbol, op, "Pending short",Lot/2, ShortPendingEntryPrice, ShortSL, (ShortTP+ShortPendingEntryPrice)/2, MagicNumber+1);
  }

}


//+------------------------------------------------------------------+
bool DoesTradeExist(string symbol, int type, double MagicNumber)
//+------------------------------------------------------------------+
{
   //Searches for open trades
   
   if (OrdersTotal() == 0) return(false); //nothing to do

   for (int cc = OrdersTotal() - 1; cc >= 0; cc--)
   {      
      if (!OrderSelect(cc, SELECT_BY_POS) ) continue;
      if (OrderMagicNumber() == MagicNumber && OrderSymbol() == symbol && OrderType() == type) 
      {        
         return(true);         
      }
   }
   
   return(false);
   
}// DoesTradeExist()

//+------------------------------------------------------------------+
void place_order(string symbol, int type, string stype, double Lot, double PendingEntryPrice, double SL, double TP, double MagicNumber)
//+------------------------------------------------------------------+
{
   int ticket,err;

   if (!DoesTradeExist(symbol, type, MagicNumber))
   {
      while (!IsTradeAllowed()) Sleep(500); // wait for Trade to be allowed(free context)

      ticket = OrderSend(symbol, type, Lot, PendingEntryPrice, 0, SL, TP, TradeComment, MagicNumber, 0,Green);
      if (ticket < 0)
      {
         err=GetLastError();
         Alert(symbol+":"+stype+" FAILED ("+err+"): "+ErrorDescription(err));
         return;
      } else {
         Alert(symbol+":"+stype+" at "+DoubleToStr(PendingEntryPrice,Digits)+" TP="+DoubleToStr(TP,Digits)+",SL="+DoubleToStr(SL,Digits));
      }
   }

}

//+------------------------------------------------------------------+
double LotSize(double Risk)
//+------------------------------------------------------------------+
{
  //----------------------- MONEY MANAGEMENT FUNCTION  
    double lotMM = /*MathCeil*/(AccountFreeMargin() *  Risk / 1000) / 100;

  Alert ("AccountFreeMargin()="+AccountFreeMargin()+" lot="+lotMM);
	  
/*
	  if(AccountIsMicro==false) //normal account
	  {
	     if(lotMM < 0.1)                  lotMM = Lot;
	     if((lotMM > 0.5) && (lotMM < 1)) lotMM = 0.5;
	     if(lotMM > 1.0)                  lotMM = MathCeil(lotMM);
	     if(lotMM > 100)                  lotMM = 100;
	  }
	  else //micro account
	  {
	     if(lotMM < 0.01)                 lotMM = Lot;
	     if(lotMM > 1.0)                  lotMM = MathCeil(lotMM);
	     if(lotMM > 100)                  lotMM = 100;
	  }
*/	  
	  return (lotMM);
}


